@@ -2,7 +2,7 @@
 from .utils import digattr
 
 from decimal import Decimal
-from datetime import datetime, date, time
+from datetime import datetime
 
 class Field(object):
     type_class = None
@@ -74,9 +74,9 @@ class TimeField(Field):
 
 
 class SerialiserField(Field):
-    def __init__(self, *args, **kwargs):
+    def __init__(self, serialiser, *args, **kwargs):
         super(SerialiserField, self).__init__(*args, **kwargs)
-        self.serialiser = self.kwargs.pop('serialiser')
+        self.serialiser = serialiser
 
     def deflate(self, name, obj, data, **kwargs):
         src = self._get_attrname(name)
@@ -94,9 +94,9 @@ class SerialiserField(Field):
 
 
 class ManySerialiserField(Field):
-    def __init__(self, *args, **kwargs):
+    def __init__(self, serialiser, *args, **kwargs):
         super(ManySerialiserField, self).__init__(*args, **kwargs)
-        self.serialiser = self.kwargs.pop('serialiser')
+        self.serialiser = serialiser
 
     def deflate(self, name, obj, data, **kwargs):
         src = self._get_attrname(name)
