@@ -1,19 +1,18 @@
 
-from django.conf.urls import url
+from django.conf.urls import url, patterns, include
 from django.core.paginator import Paginator
-from django.shortcuts import get_object_or_404
+from django.views.decorators.http import require_http_methods
 
 from collections import defaultdict
 
-from . import auth
 from . import http
 from . import engine
 
 def accepts(*verbs):
-    '''Annotate a method with the HTTP verbs it accepts'''
+    '''Annotate a method with the HTTP verbs it accepts, and enforce it.'''
     def _inner(method):
         setattr(method, '_accepts', verbs)
-        return method
+        return require_http_methods([x.upper() for x in verbs])(method)
     return _inner
 
 class BasePublisher(object):
@@ -23,7 +22,6 @@ class BasePublisher(object):
         self.args = args
         self.kwargs = kwargs
 
-    # XXX Need some names/labels to build url pattern names?
     @classmethod
     def patterns(cls, api_name=None):
         '''
@@ -43,20 +41,21 @@ class BasePublisher(object):
         if api_name:
             name = '%s_%s' % (api_name, cls.api_name)
         else:
-            name = self.api_name
+            name = cls.api_name
 
         return [
-            url(r'^object/(?P<object_id>[-\w]+)/(?P<action>\w+)/(?P<argument>.+)/?$',
-                view,
-                name='%s_object_action_arg' % name,
-            ),
-            url(r'^object/(?P<object_id>[-\w]+)/(?P<action>\w+)/?$',
-                view,
-                name='%s_object_action' % name,
-            ),
-            url(r'^object/(?P<object_id>[-\w]+)/?$',
-                view,
-                name='%s_object_default' % name,
+            url(r'^object/(?P<object_id>[-\w]+)/',
+                include(patterns('',
+                    url(r'^(?P<action>\w+)/(?P<argument>.+)/?$', view,
+                        name='%s_object_action_arg' % name
+                    ),
+                    url(r'^(?P<object_id>[-\w]+)/(?P<action>\w+)/?$', view,
+                        name='%s_object_action' % name,
+                    ),
+                    url(r'^$', view,
+                        name='%s_object_default' % name,
+                    ),
+                ))
             ),
             url(r'^(?P<action>\w+)/(?P<argument>.+)/$',
                 view,
@@ -72,6 +71,7 @@ class BasePublisher(object):
             ),
         ]
 
+
     def dispatch(self, request, action='default', object_id=None, **kwargs):
         '''View dispatcher called by Django'''
         self.action = action
@@ -85,14 +85,15 @@ class BasePublisher(object):
             raise http.Http404
         # Do we need to pass any of this?
         try:
-            return handler(request, action=action, object_id=object_id, **kwargs)
+            return handler(request, action=action, object_id=object_id,
+                **kwargs
+            )
         except http.BaseHttpResponse as response:
             return response
 
     @classmethod
     def index(cls):
         '''Return details about which handlers exist on this publisher.'''
-        # XXX Allow verb-generic methods to be annotated
         list_handlers = defaultdict(list)
         object_handlers = defaultdict(list)
         for name in dir(cls):
@@ -180,7 +181,7 @@ class Publisher(engine.JsonEngine, BasePublisher):
         serialiser_kwargs = response_kwargs.pop('serialiser_kwargs', None)
         if serialiser_kwargs is None:
             serialiser_kwargs = self.get_serialiser_kwargs()
-        data = serialiser.deflate_object(obj, **serialiser_kwargs)
+        data = serialiser.object_deflate(obj, **serialiser_kwargs)
         return self.create_response(data, **response_kwargs)
 
     def create_response(self, content, **response_kwargs):
@@ -195,7 +196,7 @@ class Publisher(engine.JsonEngine, BasePublisher):
 
         serialiser = self.get_serialiser()
         serialiser_kwargs = self.get_serialiser_kwargs()
-        data['objects'] = serialiser.deflate_list(data['objects'], **serialiser_kwargs)
+        data['objects'] = serialiser.list_deflate(data['objects'], **serialiser_kwargs)
         return self.create_response(data)
 
     def object_get_default(self, request, object_id, **kwargs):
@@ -204,86 +205,3 @@ class Publisher(engine.JsonEngine, BasePublisher):
         return self.render_single_object(obj)
 
 
-class ModelPublisher(Publisher):
-    '''A Publisher with useful methods to publish Models'''
-
-    @property
-    def model(self):
-        '''By default, we try to get the model from our serialiser'''
-        # XXX Should this call get_serialiser?
-        return self.serialiser._meta.model
-
-    # Auto-build serialiser from model class?
-
-    def get_object_list(self):
-        return self.model.objects.all()
-
-    def get_object(self, object_id):
-        return get_object_or_404(self.get_object_list(), pk=object_id)
-
-
-class ModelFormMixin(object):
-    '''Provide writable models using form validation'''
-
-    initial = {}
-    form_class = None
-
-    # Here we mimic the FormMixin from django
-    def get_initial(self):
-        """
-        Returns the initial data to use for forms on this view.
-        """
-        return self.initial.copy()
-
-    def get_form_class(self):
-        """
-        Returns the form class to use in this view
-        """
-        return self.form_class
-
-    def get_form(self, form_class):
-        """
-        Returns an instance of the form to be used in this view.
-        """
-        return form_class(**self.get_form_kwargs())
-
-    def get_form_kwargs(self, **kwargs):
-        """
-        Returns the keyword arguments for instantiating the form.
-        """
-        kwargs.setdefault('initial', self.get_initial())
-        if self.request.method in ('POST', 'PUT'):
-            kwargs.update({
-                'data': self.request.POST,
-                'files': self.request.FILES,
-            })
-        return kwargs
-
-    def list_post_default(self, request, *args, **kwargs):
-        form_class = self.get_form_class()
-        form = self.get_form(form_class)
-
-        if form.is_valid():
-            obj = form.save()
-            return self.render_single_object(obj)
-
-        # return errors
-
-
-    def object_put_default(self, request, object_id, *args, **kwargs):
-        obj = self.get_object(object_id)
-        form_class = self.get_form_class()
-        form = self.get_form(form_class, instance=obj)
-
-        if form.is_valid():
-            obj = form.save()
-            return self.render_single_object(obj)
-
-        # return errors
-
-    def object_delete_default(self, request, object_id, *args, **kwargs):
-        obj = self.get_object(object_id)
-        # XXX Some sort of verification?
-        obj.delete()
-        return http.NoContent()
-
